
class Constants():
    ID = "id"
    STATE = "state"
    ACTIVE = "Active"
    NAME = "name"
    LATITUDE = "latitude"
    LONGITUDE = "longitude"
    ADDRESS = "address"
    ZIP = "zip"
    CITY = 'city'
    VEHICLES = "vehicles"
    TYPE = "type"
    BATTERY_LEVEL = "ebike_battery_level"
    BIKE = "Bike"
    EBIKE = "E-Bike"
